summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoParagCounter.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /lib/kotext/KoParagCounter.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kotext/KoParagCounter.h')
-rw-r--r--lib/kotext/KoParagCounter.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/kotext/KoParagCounter.h b/lib/kotext/KoParagCounter.h
index 4f32df58..dbedb3e8 100644
--- a/lib/kotext/KoParagCounter.h
+++ b/lib/kotext/KoParagCounter.h
@@ -197,10 +197,10 @@ public:
private:
/** Return our tqparent paragraph, if there is such a thing. For a paragraph "1.1.",
* the tqparent is the paragraph numbered "1.".
*/
- KoTextParag *tqparent( const KoTextParag *paragraph );
+ KoTextParag *parent( const KoTextParag *paragraph );
Numbering m_numbering:3; // Numbering (maximum value: 8)
bool m_restartCounter:1;
@@ -227,7 +227,7 @@ private:
* number of this counter -1
* text of this counter TQString()
* width of the label -1
- * tqparent (KoTextParag *)-1
+ * parent (KoTextParag *)-1
* the format that was used to calculate the width 0
*/
struct
@@ -235,7 +235,7 @@ private:
int number;
TQString text;
int width;
- KoTextParag *tqparent;
+ KoTextParag *parent;
KoTextFormat * counterFormat;
} m_cache;
};
@@ -197,10 +197,10 @@ public:
private:
- /** Return our tqparent paragraph, if there is such a thing. For a paragraph "1.1.",
- * the tqparent is the paragraph numbered "1.".
+ /** Return our parent paragraph, if there is such a thing. For a paragraph "1.1.",
+ * the parent is the paragraph numbered "1.".
*/